## 2.0.0.20250809 (2025-08-09)

Mark stub-only private symbols as `@type_check_only` in third-party stubs (#14545)

## 2.0.0.20250111 (2025-01-11)

Officially drop Python 3.8 support (#13386)

## 2.0.0.20241229 (2024-12-29)

Fix todo in pycocotools (#13182)

Adds numpy types.
All the types were already there as comments.

## 2.0.0.20240806 (2024-08-06)

Bump mypy to 1.11.1 (#12463)

## 2.0.0.20240106 (2024-01-06)

Update typing_extensions imports in third-party stubs (#11245)

## 2.0.0.5 (2023-11-24)

Third-party stubs: remove unused `type: ignore`s (#11063)

## 2.0.0.4 (2023-07-20)

Add an upstream_repository field to METADATA.toml (#10487)

Closes: #10478

## 2.0.0.3 (2023-03-27)

Add default values for third-party stubs beginning with 'P' (#9957)

## 2.0.0.2 (2023-03-17)

[pycocotools] Fix COCOeval.eval and Params.areaRng (#9897)

* Rename `_EvaluationResult` to `_ImageEvaluationResult`
* Add new `_EvaluationResult`
* Fix type of `COCOeval.eval`
* Correct Params.areaRng which is in fact a list of pairs

## 2.0.0.1 (2023-02-21)

Stubtest settings: change `ignore_missing_stub` default to `false` (#9779)

If you're reading about this commit from an autogenerated changelog entry, this should have no user-visible impact on how the stubs are interpreted by a type checker; it's just an internal change to how typeshed's tests work.

## 2.0.0.0 (2022-11-28)

Add stubs for pycocotools (#9086)

Co-authored-by: Alex Waygood <Alex.Waygood@Gmail.com>

